@@ -1,8 +1,10 @@
-from .commands import configure, import_config, load_config, load_spec, import_spec, env
+from .commands import CONFIG, configure, import_config, load_config, load_spec, import_spec, env
 from .validation import required, optional, one_of, ValidationError
+from .attrs import attrs
 
 
 __all__ = [
+    'attrs',
     'configure',
     'import_config',
     'load_config',
@@ -13,4 +15,5 @@ __all__ = [
     'env',
     'one_of',
     'ValidationError',
+    'CONFIG',
 ]
